Symbolic constants identifying the type of a JSON value.
JSON_T_NULL.RdThese constants are used by handler functions that are called when a JSON value is encountered by the JSON parser. These identify the type of the JSON value. The values will already have been converted, but the start and end array and object events won't have a type.
JSON_parser.h code from http://www.json.org.